@@ -1,6 +1,7 @@
 from Crypto.PublicKey import RSA
 from Crypto.Cipher import PKCS1_v1_5 as Cipher_pkcs1_v1_5
-import base64, os
+import base64
+import os
 from Crypto import Random
 from Crypto.Hash import SHA1
 from Crypto.Signature import pkcs1_15
@@ -9,9 +10,11 @@ from Crypto.Signature import pkcs1_15
 class CRSAHelper:
     def __init__(self, *args):
         if args:
-            self.basePath = os.path.join(os.getcwd(), args)
+            self.basePath = os.path.join(os.getcwd(), *args)
         else:
             self.basePath = os.getcwd()
+        if not os.path.exists(self.basePath):
+            os.makedirs(self.basePath)
 
     def create_key(self):
         # 伪随机数生成器
@@ -57,5 +60,6 @@ class CRSAHelper:
     def signature(self, str):  # 公钥签名
         public_key = RSA.importKey(self.get_public_key())
         hash_obj = SHA1.new(bytearray(str, encoding='utf-8'))
-        signature = base64.b64encode(pkcs1_15.new(public_key).sign(hash_obj)).decode()
+        signature = base64.b64encode(pkcs1_15.new(
+            public_key).sign(hash_obj)).decode()
         return signature
